# A DeepLearning ToolKit

- Torch and mxnet Based

## Current Function

- calc acc
- batch data for convenience way 
- wrap list to tensor/ndarray

## Update log

### 0.3-beta-5

- +Model config class
- +logger class
